@@ -13,7 +13,7 @@ use Socket qw(
     inet_aton inet_ntoa pack_sockaddr_in unpack_sockaddr_in
 );
 
-our $VERSION = '1.95_01';
+our $VERSION = '1.90';
 
 my %PROTOS = (
     tcp => SOCK_STREAM,
@@ -100,15 +100,15 @@ sub connect {
     my ($self) = @_;
 
     my $addr = eval { inet_aton( $self->{saddr} ) }
-        or croak 'Could not pack IP address in connect'
+        or croak 'Could not pack IP address'
         . ( $EVAL_ERROR ? ": $EVAL_ERROR" : q{} );
 
     my $sockaddr = eval { pack_sockaddr_in( $self->{sport}, $addr ) }
-        or croak 'Could not create sockaddr_in structure in connect'
+        or croak 'Could not create sockaddr_in structure'
         . ( $EVAL_ERROR ? ": $EVAL_ERROR" : q{} );
 
     socket my $sock, AF_INET, $PROTOS{ $self->{proto} }, 0
-        or croak "Could not open server socket in connect: $OS_ERROR";
+        or croak "Could not open server socket: $OS_ERROR";
     connect $sock, $sockaddr
         or croak "Could not connect to server socket: $OS_ERROR";
 
@@ -134,7 +134,7 @@ Test::Net::SSLeay::Socket - Socket class for the Net-SSLeay test suite
 
 =head1 VERSION
 
-This document describes version 1.95_01 of Test::Net::SSLeay::Socket.
+This document describes version 1.90 of Test::Net::SSLeay::Socket.
 
 =head1 SYNOPSIS
 
@@ -310,12 +310,14 @@ the version of OpenSSL or LibreSSL you are using.
 
 Originally written by Chris Novakovic.
 
-Maintained by Chris Novakovic and Heikki Vatiainen.
+Maintained by Chris Novakovic, Tuure Vartiainen and Heikki Vatiainen.
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2020- Chris Novakovic <chris@chrisn.me.uk>.
 
+Copyright 2020- Tuure Vartiainen <vartiait@radiatorsoftware.com>.
+
 Copyright 2020- Heikki Vatiainen <hvn@radiatorsoftware.com>.
 
 This module is released under the terms of the Artistic License 2.0. For
